@@ -57,13 +57,13 @@ class Command(object):
             name = self.__class__.__name__.lower()
         self.name = name
         self.config = config
-        self.checkConfig(config)
 
     def checkConfig(self, config):
         return # No checking performed by default.
 
-    def help(self):
-        return self.__doc__
+    @classmethod
+    def help(cls):
+        return cls.__doc__
 
     def run(self, args, environ):
         raise NotImplementedError
@@ -310,7 +310,7 @@ class status(Command):
             print 'Process is running at pid %s' % pid
             sys.exit(0)
         else:
-            print 'Process is not running.' % pid
+            print 'Process is not running.'
             sys.exit(1)
 
 class annotate(Command):
@@ -331,7 +331,7 @@ class ArbitraryCommand(Command):
                                        % self.name)
 
     def help(self):
-        return self.command.help()
+        return self.command.help() or ''
     
     def run(self, args, environ):
         self.chdir()
@@ -339,12 +339,12 @@ class ArbitraryCommand(Command):
         os.system(self.command.command())
         #self.execute(environ, self.command.command())
 
-commands = OrderedDict([
-    ('start', start),
-    ('stop', stop),
-    ('kill', kill),
-    ('restart', restart),
-    ('status', status),
-    ('debug', debug),
-    ('annotate', annotate),
-])
+commands = [
+    'start',
+    'stop',
+    'kill',
+    'restart',
+    'status',
+    'debug',
+    'annotate',
+]
